pyRdfa Package
==============

:mod:`pyRdfa` Package
---------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`embeddedRDF` Module
-------------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.embeddedRDF
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`initialcontext` Module
----------------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.initialcontext
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`options` Module
---------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.options
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parse` Module
-------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.parse
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`property` Module
----------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.property
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`state` Module
-------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.state
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`termorcurie` Module
-------------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.termorcurie
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: rdflib.plugins.parsers.pyRdfa.utils
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    rdflib.plugins.parsers.pyRdfa.extras
    rdflib.plugins.parsers.pyRdfa.host
    rdflib.plugins.parsers.pyRdfa.rdfs
    rdflib.plugins.parsers.pyRdfa.transform

